Sub BackFactor11 (AtNum,AtWht,rho,E0,Ec,Dia,eta,etaP,R)

     'Calculation of R-factor for the spherical particles
     'Van Borm and Adams (1991)
     'Input parameters:  AtNum   :   Average atomic number
     '                   AtWht   :   Average atomic weight
     '                   rho     :   Average density in g/cm^3
     '                   E0      :   Incident beam energy in keV
     '                   Ec      :   Critical excitation energy in keV
     '                   Dia     :   Particle diamater in microns
     '                   eta     :   Eta for bulk,flat non-tilted samples
     '                   etaP    :   Eta for particles
     'Output parameter:  R       :   R-factor

     'Electron penetration range, Whelan's equation
     Z=AtNum
     A=AtWht
     Dia=Dp
     d=0.033*(A/(rho*Z))*(E0^1.69-Ec^1.69)
     if (d*0.3)<=Dp then       'for particle with Dia<0.3*d
	 eta=(eta1/d*0.3)*Dp
	 U0=E0/Ec
	 E1=(E0^1.69-((Z*rho)/(0.033*A))*Dp)^0.5917
	 U1=E1/Ec
	 U11=0.5*U1*(1-etaP)
	 U=0.5*U0*(1-etaP)
	 a=(U-1)^1.67-(U11-1)^1.67
	 b=(U0-1)^1.67-(U1-1)^1.67
	 R=1-etaP*(a/b)
     else                      'for particle with Dia>0.3*d
	 U0=E0/Ec
	 a=0.5*U0*(1+eta)-1
	 b=U0-1
	 R=1-eta*(a/b)^1.67
     end if

End Sub
