Sub BackFactor8 (E0,Ec,eta,alpha,R)

     'Backscattering factor (R-Factor), Czyzewski (1985)

     'Input parameters: E0    :  Incident beam energy in keV
     '                  Ec    :  Critical excitation energy in keV
     '                  eta   :  Backscattering coefficient
     '		        alpha :  Specimen tilt angle in degrees
     'Output parameter: R     :  Backscattering factor

     alpha=alpha*0.017453
     U0=E0/Ec
     k=1.6
     p=(0.8+2*eta)*log(1/eta)
     s=0.1054*(2^p-1+1/(2.25*cos(alpha)^p))
     a=1/((U0-1)^1.67)
     'Numerical integration of the differential expression for the
     'energy distribution of backscattered electrons by trapezoidal rule
     'Because the Basic not permit use DEF FN in subroutine,we normally
     'used three times differental function for BSE energy distribution
     n=100
     u1=1
     u2=U0-0.0001
     w=(u2-u1)/n
     h1=k*p*s*eta*(u1^(k-1)/U0^(k-1))/((U0*(1-u1^k/U0^k)^(1+p))*_
	(1-s+s/(1-u1^k/U0^k)^p)^2)*(u1-1)^1.67
     h2=k*p*s*eta*(u2^(k-1)/U0^(k-1))/((U0*(1-u2^k/U0^k)^(1+p))*_
	(1-s+s/(1-u2^k/U0^k)^p)^2)*(u2-1)^1.67
     es=h1+h2
     sum=0
     for i=1 to n-1
	   U=U1+i*w
	   h3=k*p*s*eta*(u^(k-1)/U0^(k-1))/((U0*(1-u^k/U0^k)^(1+p))*_
	      (1-s+s/(1-u^k/U0^k)^p)^2)*(u-1)^1.67
	   sum=sum+h3
     next i
     total=(es+2*sum)*w/2
     R=1-(a*total)

End Sub