Sub BackScatCoef20 (E0,Zs,Zf,rhoF,eta,t)

'Hunger and Rogaschewski (1986) backscattering coefficient for thin film-substrat combination
'Input parameters:  E0   = incident beam energy in keV
'                   Zs   = atomic number of substrate
'                   Zf   = atomic number of thin film
'                   rhoF = density of film in g/cm^3
'                   eta  = backscattering coefficient for thin film-substrat
'Output parameters: t    = thickness of thin film on substrate in microns

   'Eta for bulk substrat,Hunger and Kuchler (1979)
    Ks=0.19036-0.2236*log(Zs)+0.1292*(log(Zs))^2-0.01491*(log(Zs))^3
    ms=0.1382-0.9211*Zs^(-0.5)
    etaS=Ks*E0^ms
   'Eta for bulk film,Hunger and Kuchler (1979)
    Kf=0.19036-0.2236*log(Zf)+0.1292*(log(Zf))^2-0.01491*(log(Zf))^3
    mf=0.13982-0.9211*Zf^(-0.5)
    etaF=Kf*E0^mf
    a1=(2.153*Zf-14.789)/(3.706*Zf+17.822)
    a2=(-0.1147*Zf+24.591)/(3.706*Zf+17.822)
    t=(0.00682*Zf+0.821)*E0^(1.801-0.00318*Zf)  'mass thickness 0.5
    x=(eta-etaS)/(etaF-etaS)
    y=0.5*log((1+x)/(1-x))    'area tan hipebolicus
    s1=(-a1+(a1^2-4*a2*(-y))^0.5)/(2*a2)
    s2=(-a1-(a1^2-4*a2*(-y))^0.5)/(2*a2)
    s1=s1*t         'mass thickness for s1
    s1=s1/rhof
    s1=s1/100
    t=s1
    s2=s2*t         'mass thickness for s2
    s2=s2/rhof
    s2=s2/100

End Sub
