Sub Effic (E,Det$,tAu,tD,tBe,tC,tDiam,tBN,tQ,tSiN,tM,tAl,tIce,t,alpha,Eff)

     'Si(Li) and Ge X-Ray detector efficiency, Zaluzec and Holton (1984)

     'Input parameters:

     'E      :   Energy in keV
     'Det$   :   Detector type (Si or Ge)7
     'tAu    :   Au layer thickness in Angstroms
     'tD     :   Si or Ge dead layer thickness in Angstroms
     'tBe    :   Be thickness in microns
     'tC     :   Carbon thickness in Angstroms
     'tDiam  :   Diamond thickness in microns
     'tBN    :   BN thickness in microns
     'tQ     :   Kevex Quantum thickness in microns
     'tSiN   :   Si3N4 thickness in microns
     'tM     :   Maylar thickness in microns
     'tPy    :   Pyrolene thickness in microns
     'tAl    :   Al thickness in Angstroms
     'tIce   :   Ice (as Oxygen) thickness in Angstroms
     't      :   Detector thickness in mm
     'alpha  :   X-ray incidence angle to the crystal

     'Output parameter:

     'Eff    :   Efficiency

     'Assume Si Dead layer and Ge Dead layer are the same to simplify
     'the number of input questions and also Si Active and Ge Active
     'thickness are the same.

     'Now convert everythins into units of cm
     tAu=tAu*1e-8
     tD=tD*1e-8
     tBe=tBe*1e-4
     tC=tC*1e-8
     tDiam=tDiam*1e-4
     tBN=tBN*1e-4
     tQ=tQ*1e-4
     tSiN=tSiN*1e-4
     tM=tM*1e-4
     tPy=tPy*1e-4
     tAl=tAl*1e-8
     tIce=tIce*1e-8
     t=t*0.1


     'Mass absorption coefficients, Zaluzec and Holton (1984) and
     'Thinh and Leroux (1979).
     cosa=cos(alpha/57.2985)
     d$=ucase$(d$)
     WL=12.3981/E                              'wavelength in Angstroms
     Z=1                                       'Hydrogen
      if E>0.679 and E<1.487 then
	    C=0.001472
	    n=3.359
	    M1=C*WL^n
      elseif E>0.395 and E<0.679 then
	    C=0.001816
	    n=3.285
	    M1=C*WL^n
      elseif E>0.185 and E<0.395 then
	    C=0.002138
	    n=3.231
	    M1=C*WL^n
      else
	    call Mac4 (Z,E,M)
	    M1=M
      end if

     Z=4                                       'Beryllium
     if E>0.679 and E<1.487 then
	    C=0.3102
	    n=3.001
	    M4=C*WL^n
     elseif E>0.285 and E<0.679 then
	    C=0.5060
	    n=2.831
	    M4=C*WL^n
     elseif E>0.185 and E<0.285 then
	    C=2.2480
	    n=2.419
	    M4=C*WL^n
     else
	    call Mac4 (Z,E,M)
	    M4=M
     end if

     Z=5                                       'Boron
     call Mac4 (Z,E,M)
     M5=M

     Z=6                                       'Carbon
     if E>0.705 and E<1.487 then
	    C=1.9660
	    n=2.788
	    M6=C*WL^n
     elseif E>0.285 and E<0.705 then
	    C=4.1290
	    n=2.529
	    M6=C*WL^n
     elseif E>0.185 and E<0.285 then
	    C=0.2572
	    n=2.404
	    M6=C*WL^n
     else
	    call Mac4 (Z,E,M)
	    M6=M
     end if

     Z=7                                       'Nitrogen
     call Mac4 (Z,E,M)
     M7=M

     Z=8                                       'Oxygen
     if E>0.532 and E<1.487 then
	    C=6.9980
	    n=2.573
	    M8=C*WL^n
     elseif E>0.185 and E<0.532 then
	    C=0.4810
	    n=2.479
	    M8=C*WL^n
     else
	    call Mac4 (Z,E,M)
	    M8=M
     end if

     Z=13                                      'Aluminium
     if E>0.556 and E<1.487 then
	    C=1.2860
	    n=2.712
	    M13=C*WL^n
     elseif E>0.185 and E<0.556 then
	    M13=-7.059e-4*WL^4-4.815e-2*WL^3+2.579e1*WL^2-3.664e2*WL+1801.0
     else
	    call Mac4 (Z,E,M)
	    M13=M
     end if
					       'Silicon
     Z=14
     if E>0.637 and E<1.485 then
	    C=1.759
	    n=2.706
	    M14=C*WL^n
     elseif E>0.185 and E<0.637 then
	    M14=-2.407e-1*WL^3+3.983e1*WL^2-5.270e2*WL+2278.0
     else
	    call Mac4 (Z,E,M)
	    M14=M
     end if

     Z=32                                      'Germanium
     call Mac4 (Z,E,M)
     M32=M

     Z=79                                      'Gold
     if E>0.776 and E<1.487 then
	    C=41.17
	    n=1.906
	    M79=C*WL^n
     elseif E>0.185 and E<0.776 then
	    M79=-4.411e-4*WL^5+9.878e-2*WL^4-8.218*WL^3+3.020e2*WL^2-4.466e3*WL+29660.0
     else
	    call Mac4 (Z,E,M)
	    M79=M
     end if


     'Au layer, density data (DTSA NIST program)
     SumAu=(M79*19.3*tAu)/cosa

     'Si or Ge dead layer, density data (DTSA NIST program)
     if Det$="SI" then SumD=(M14*2.33*tD)/cosa
     if Det$="GE" then SumD=(M32*5.307*tD)/cosa

     'Be window, density data (DTSA NIST program)
     SumBe=(M4*1.82*tBe)/cosa

     'Carbon layer, density=2.34, Hovington et al. (1993)
     SumC=(M6*2.34*tC)/cosa

     'Diamond layer, density data (DTSA NIST program)
     SumDiam=(M6*3.515*tDiam)/cosa

     'BN layer, 91% B and 9 % N, H-1, density data (Pouchou, 1991)
     MBN=0.91*M5+0.09*M7
     SumBN=(MBN*1.40*tBN)/cosa

     'Kevex Quantum, all data was graphicaly extracted from the graph
     'energy (keV)-transmission (%), catalog Quantum, Kevex (1987)
     if E=0 then
	 MQ=0
     elseif E>0 and E<2.99 then
	 A1=46453
	 A2=19016
	 t1=0.1389
	 t2=0.8541
	 MQ=A1*exp(-E/t1)+A2*exp(-E/t2)
     else
	 MQ=0
     end if
     SumQ=(MQ*1.40*tQ)/cosa

     'Si3N4, 59.942 % Si, 40.058 % N, density data (DTSA NIST program)
     MSiN=0.59942*M14+0.40058*M7
     SumSiN=(MSiN*3.44*tSiN)/cosa

     'Maylar layer, 92.258 % C and 7.742 % H, density data (DTSA NIST program)
     MM=0.92258*M6+0.07742*M1
     SumM=(MM*1.37*tM)/cosa

     'Pyrolene thickness, C8H8, density data (Zaluzec and Holton (1984))
     MPy=0.9226*M6+0.0774*M7
     SumPy=(MPy*1.11*tPy)/cosa

     'Al layer, density data (DTSA NIST program)
     SumAl=(M13*2.69*tAl)/cosa

     'Ice layer, density data (Zaluzec and Holton (1984))
     SumIce=(M8*0.92*tIce)/cosa

     'Detector active thickness, density data (DTSA NIST program)
     if Det$="SI" then Sum=(M14*2.33*t)/cosa
     if Det$="GE" then Sum=(M32*5.307*t)/cosa
     if Sum>=2000 then Sum=2000

     Sum1=SumAu+SumD+SumBe+SumDiam+SumBN+SumQ+SumSiN+SumM+SumAl+SumIce
     Ef=exp(-Sum1)*(1-exp(-Sum))

End Sub


Sub Mac4 (Z,E,M)

     'Subroutine:Mac's calculations,Thinh and Leroux (1979)
     'Input parameters:    Z     :    atomic number of absorber
     '                     E     :    energy of emission line in keV
     'Output parameters:   M     :    mass absorption coefficient

     'read data from random file for given Z
     x=1+25*(Z-1)
     open"mac4.rnd" for random as #1 len=4
     field #1,4 as c$
     dim c(2350),c$(2350)
     get #1,x:Z=cvs(c$):get #1,x+1:C=cvs(c$):get #1,x+2:K=cvs(c$)
     get #1,x+3:n=cvs(c$):get #1,x+4:E1=cvs(c$):get #1,x+5:CE1=cvs(c$)
     get #1,x+6:nE1=cvs(c$):get #1,x+7:L1=cvs(c$):get #1,x+8:nL1=cvs(c$)
     get #1,x+9:L2=cvs(c$):get #1,x+10:nL2=cvs(c$):get #1,x+11:L3=cvs(c$)
     get #1,x+12:nL3=cvs(c$):get #1,x+13:M1=cvs(c$):get #1,x+14:nM1=cvs(c$)
     get #1,x+15:M2=cvs(c$):get #1,x+16:nM2=cvs(c$):get #1,x+17:M3=cvs(c$)
     get #1,x+18:nM3=cvs(c$):get #1,x+19:M4=cvs(c$):get #1,x+20:nM4=cvs(c$)
     get #1,x+21:M5=cvs(c$):get #1,x+22:nM5=cvs(c$):get #1,x+23:N1=cvs(c$)
     get #1,x+24:nN1=cvs(c$)
     close #1

     'Special equations
     if Z=1 then
	 if E>=1.0 and E<=2.0 then
		 D=0.01460:n=3.00344
		 M=D*(12.3981/E)^n
	 elseif E>=2.0 and E<=3.50 then
		 D=0.05890:n=2.23900
		 M=D*(12.3981/E)^n
	 elseif E>=3.50 and E<=4.0 then
		 D=0.07434:n=2.05500
		 M=D*(12.3981/E)^n
	 elseif E>=4.0 and E<=6.0 then
		 D=0.27795:n=0.88900
		 M=D*(12.3981/E)^n
	 elseif E>=6.0 and E<=9.20 then
		 D=0.43231:n=0.28100
		 M=D*(12.3981/E)^n
	 elseif E>=9.20 and E<=40.0 then
		 D=0.44767:n=0.16280
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=2 then
	 if E>=3.70 and E<=6.0 then
		 D=0.10107:n=1.89541
		 M=D*(12.3981/E)^n
	 elseif E>=6.0 and E<=9.50 then
		 D=0.19040:n=1.02279
		 M=D*(12.3981/E)^n
	 elseif E>=9.50 and E<=18.0 then
		 D=0.21026:n=0.65018
		 M=D*(12.3981/E)^n
	 elseif E>=18.0 and E<=40.0 then
		 D=0.18714:n=0.33771
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=3 then
	 if E>=5.90 and E<=8.80 then
		 D=0.18233:n=2.29188
		 M=D*(12.3981/E)^n
	 elseif E>=8.80 and E<12.50 then
		 D=0.26263:n=1.22738
		 M=D*(12.3981/E)^n
	 elseif E>=12.50 and E<=19.20 then
		 D=0.26156:n=0.73083
		 M=D*(12.3981/E)^n
	 elseif E>=19.20 and E<=40.0 then
		 D=0.22601:n=0.39674
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=4 then
	 if E>=8.0 and E<=12.50 then
		 D=0.38680:n=2.16808
		 M=D*(12.3981/E)^n
	 elseif E>=12.50 and E<=19.80 then
		 D=0.38371:n=1.18826
		 M=D*(12.3981/E)^n
	 elseif E>=19.80 and E<=40.0 then
		 D=0.27424:n=0.47075
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=5 then
	 if E>=10.50 and E<=15.0 then
		 D=0.62897:n=2.37589
		 M=D*(12.3981/E)^n
	 elseif E>=15.0 and E<=21.0 then
		 D=0.49970:n=1.16813
		 M=D*(12.3981/E)^n
	 elseif E>=21.0 and E<=31.0 then
		 D=0.40524:n=0.77056
		 M=D*(12.3981/E)^n
	 elseif E>=31.0 and E<=40.0 then
		 D=0.29211:n=0.41335
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=6 then
	 if E>=13.0 and E<=19.50 then
		 D=1.10987:n=2.19895
		 M=D*(12.3981/E)^n
	 elseif E>=19.50 and E<=27.50 then
		 D=0.74709:n=1.32494
		 M=D*(12.3981/E)^n
	 elseif E>=27.50 and E<=40.0 then
		 D=0.40943:n=0.57000
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=7 then
	 if E>=15.0 and E<=21.0 then
		 D=1.46410:n=2.00119
		 M=D*(12.3981/E)^n
	 elseif E>=21.0 and E<=30.0 then
		 D=1.06418:n=1.39578
		 M=D*(12.3981/E)^n
	 elseif E>=30.0 and E<=40.0 then
		 D=0.60023:n=0.74774
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=8 then
	 if E>=17.20 and E<=25.0 then
		 D=1.83450:n=1.85350
		 M=D*(12.3981/E)^n
	 elseif E>=25.0 and E<=40.0 then
		 D=1.07154:n=1.08685
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=9 then
	 if E>=20.0 and E<=28.50 then
		 D=2.41791:n=1.84635
		 M=D*(12.3981/E)^n
	 elseif E>=28.50 and E<=40.0 then
		 D=1.19931:n=1.00398
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=10 then
	 if E<23.0 then
		 goto 10
	 elseif E>=23.0 and E<=30.0 then
		 D=3.28063:n=1.92254
		 M=D*(12.3981/E)^n
	 elseif E>=30.0 and E<=40.0 then
		 D=1.79454:n=1.23982
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=11 then
	 if E>=25.0 and E<=31.0 then
		 D=3.51621:n=1.79285
		 M=D*(12.3981/E)^n
	 elseif E>=31.0 and E<=40.0 then
		 D=2.05417:n=1.20633
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=12 then
	 if E>=27.30 and E<=40.0 then
		 D=3.19488:n=1.47154
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=13 then
	 if E>=29.50 and E<=40.0 then
		 D=3.40890:n=1.41477
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=14 then
	 if E>=32.50 and E<=40.0 then
		 D=4.90164:n=1.64945
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=15 then
	 if E>=35.0 and E<=40.0 then
		 D=5.66476:n=1.67109
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     elseif Z=16 then
	 if E>=37.50 and E<=40.0 then
		 D=6.09135:n=1.63252
		 M=D*(12.3981/E)^n
	 else
		 goto 10
	 end if

     else
	10 ' General equations
	if E>K then
	    M=C*K*(12.3981/E)^n
	elseif E<E1 and E>K then
	    M=CE1*(12.3981/E)^nE1
	elseif E<K and E>L1 then
	    M=C*L1*(12.3981/E)^nL1
	elseif E<L1 and E>L2 then
	    M=C*L2*(12.3981/E)^nL2
	elseif E<L1 and E>L3 then
	    M=C*L3*(12.3981/E)^nL3
	elseif E<L3 and E>M1 then
	    M=C*M1*(12.3981/E)^nM1
	elseif E<M1 and E>M2 then
	    M=C*M2*(12.3981/E)^nM2
	elseif E<M2 and E>M3 then
	    M=C*M3*(12.3981/E)^nM3
	elseif E<M3 and E>M4 then
	    M=C*M4*(12.3981/E)^nM4
	elseif E<M4 and E>M5 then
	    M=C*M5*(12.3981/E)^nM5
	elseif E<M5 and E>N1 then
	    M=C*N*(12.3981/E)^nN1
	else
	    exit sub
	end if
     end if

End Sub
