Sub PhiRhoZ1 (Z,A,E0,Ec,rhoz,PhiRhoZ)

     'Subroutine Phi-Rho-Z function, Parobek and Brown (1978)
     'Reference:J.C.Russ, Fundamentals of Energy Dispersive
     'X-ray analysis, Butterworths, 1984, p.49-51.

     'Input parameters:    Z        :   Atomic number
     '                     A        :   Atomic weight
     '                     E0       :   Incident beam energy in keV
     '                     Ec       :   Critical excitation energy in keV
     '                     rhoz     :   Mass thickness in ug/cm^2
     'Output parameter:    PhiRhoZ  :   Phi-Rho-Z function

     'Coefficient D
     P=2.111*(1.84/Ec)^0.325
     Q=0.5945*Ec^1.42*Z^0.26
     D=Q*(E0-Ec)^P

     'Koefficient K
     B=0.5409/Ec^1.228
     F=1+(0.0595*(Z^0.7)/exp(0.0002*Z^2))
     m=(15.6578/Ec)^0.2505
     K=B*F/(E0-Ec)^m

     'Koefficient n
     n=(1.95*A)/Z^1.32

     'Koefficient R
     rhoz0=1+(1/exp(0.00015*Z))
     rhoz0=(24.487*E0*Ec^0.428/Z^1.259)*rhoz0
     R=rhoz+rhoz0

     'PhiRhoZ function
     PhiRhoZ=D*K*n*((K*R)^(n-1))*exp(-(K*R)^n)

End Sub
