Sub PhiRhoZ8 (Z,A,E0,Ec,Lines$,rhoz,PhiRhoZ)

     'Subroutine Phi-Rho-Z function, Merlet (1992)
     'Phi-Rho-Z model desribed by a double partial Gaussian expresion

     'Input parameters:   Z         :     Atomic number
     '                    A         :     Atomic weight
     '                    E0        :     Incident beam energy in keV
     '                    Ec        :     Critical excitation energy in keV
     '                    rhoz      :     Mass thickness in ug/cm^2
     '                    Lines$    :     Line code (K,L and M)
     'Output parameter:   PhiRhoZ   :     PhiRhoZ function

     Lines$=Ucase$(Lines$)
     AtWht=A
     U0=E0/Ec
     'Function Phi(0), Merlet (1992,1993)
     d1=0.02*Z
     d2=0.1*Z
     d3=0.4*Z
     rz=-0.25+0.0787*Z^3
     aa1=1.87*Z*(-0.00391*log(Z+1)+0.00721*(log(Z+1))^2-0.0001067*(log(Z+1))^3)
     aa1=aa1/(E0/30)^rz
     b1=(1/d1)*(1-(1-1/U0^d1)/(d1*log(U0)))
     b2=(1/d2)*(1-(1-1/U0^d2)/(d2*log(U0)))
     b1=(1/d3)*(1-(1-1/U0^d3)/(d3*log(U0)))
     phi0=1+aa*(0.27*b1+(1.1+5/Z)*(b2-1.1*b3))

     'X-ray range, Merlet (1993)
     aa2=1.845e-6*(2.6-0.216*E0+0.015*E0^2-0.000387*E0^3+0.00000501*EO^4)
     rhozx1=aa2*(E0^(2.2-0.0166*E0)-Ec^(2.2-0.0166*E0))*(1+2/E0^2)
     rhozx1=rhozx1/(1.078-0.015*Z^0.7)^(1.2-0.05*E0)      ' in g/cm^2

     'Position of the maximum rhozm, Merlet (1993)
     rhozm=rhozx1*(0.1+0.35*exp(-0.07*Z))/(1+10/U0^10)  ' in g/cm^2

     'Function PhiM represents the amplitude of Pho-Rho-Z
     if Lines$="K" then m=0.95
     if Lines$="L" then m=0.7
     if Lines$="M" then m=0.7
     d1=0:d2=0:a=0
     d1=1-m
     d2=7-4*exp(-0.1*Z)-m
     pz=-0.25+0.0787*Z^0.3
     a=5*(1-1/(1+Z)^0.8)*(E0/30)^pz
     'Mean ionization potential, Ruste (1979)
     J=(9.29*Z*(1+1.287*Z^(-2/3)))/1000  'in keV
     'Transmission coefficient, Zeller and Ruste (1979)
     t=rhozm/rhozx1
     tau1=(1-t)^(4.65+0.0356*Z)
     tau2=(1-t)^(1.112+0.00414*Z^2)
     tau=tau1+4.65*(tau2-tau1)/(3.54+0.0356*Z-0.00414*Z^2)
     'Ionization cross-section
     Ud=U0*(1-1.03e5*rhozm*Z/(E0^1.61*J^0.3*AtWht))^0.61
     QUd=log(Ud)/Ud^m
     QU0=log(U0)/U0^m
     b1=(Ud/U0)^d1*(log(Ud)/log(U0))*(1/d1)*(1-(1-1/Ud^d1)/(d1*log(Ud)))
     b2=(Ud/U0)^d2*(log(Ud)/log(U0))*(1/d2)*(1-(1-1/Ud^d2)/(d2*log(Ud)))
     PhiM=tau*(QUd/QU0)+a*(0.28*(1-0.5*exp(-0.1*Z))*b1+0.165*Z^0.6*b2)

     'Function Phi-Rho-Z, Merlet (1992,1993)
     if rhoz>=0 and rhoz<=rhozm then
	     beta=rhozm/(log(PhiM/Phi0))^0.5
	     PhiRhoZ=PhiM*exp(-((rhoz-rhozm)/beta)^2)
     elseif rhoz>=rhozm and rhoz<=rhozx1 then
	     alpha=0.46598*(rhozx1-rhozm)
	     PhiRhoZ=PhiM*exp(-((rhoz-rhozm)/alpha)^2)
     end if

End Sub
